Learn R Programming

sbw (version 1.0)

lalonde: The Lalonde data set

Description

Data set from the National Supported Work Demonstration used by Lalonde (1986) and Dehejia and Wahba (1999) to evaluate propensity score methods. This data set is publicly available at https://users.nber.org/~rdehejia/data/.nswdata2.html.

Usage

data(lalonde)

Arguments

Format

A data frame with 445 observations, corresponding to 185 treated and 260 control subjects, and 10 variables. The treatment assignment indicator is the first variable of the data frame; the next eight columns are the covariates; the last column is the outcome:

treatment

the treatment assignment indicator (1 if treated, 0 otherwise)

age

a covariate, measured in years

education

a covariate, measured in years

black

a covariate indicating race (1 if black, 0 otherwise)

hispanic

a covariate indicating race (1 if Hispanic, 0 otherwise)

married

a covariate indicating marital status (1 if married, 0 otherwise)

nodegree

a covariate indicating high school diploma (1 if no degree, 0 otherwise)

re74

a covariate, real earnings in 1974

re75

a covariate, real earnings in 1975

re78

the outcome, real earnings in 1978

References

Dehejia, R., and Wahba, S. (1999), "Causal Effects in Nonexperimental Studies: Reevaluating the Evaluation of Training Programs," Journal of the American Statistical Association, 94, 1053-1062.

Lalonde, R. (1986), "Evaluating the Econometric Evaluations of Training Programs," American Economic Review, 76, 604-620.